2024-08-08 Version: 1.0.5
- Generated python 2024-03-27 for APIG.

2024-08-06 Version: 1.0.4
- Update API ListGateways: update response param.


2024-08-05 Version: 1.0.3
- Update API ListHttpApiOperations: add param name.
- Update API ListHttpApis: add param name.


2024-08-05 Version: 1.0.3
- Update API ListHttpApiOperations: add param name.
- Update API ListHttpApis: add param name.


2024-07-29 Version: 1.0.2
- Update API ListDomains: add param gatewayId.


2024-07-26 Version: 1.0.1
- Update API ListHttpApis: add param publishedOnly.


2024-07-25 Version: 1.0.0
- Generated python 2024-03-27 for APIG.

